import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Icon, Modal, Tabs } from 'antd'

import zhCN from '@/locales/zh-CN/model.js'
import enUS from '@/locales/en-US/model.js'
import asyncComponent from '@/utils/asyncComponent'
import './index.scss'

const CodeMirror = asyncComponent(() => import('@/templates/zshare/codemirror'))
const { TabPane } = Tabs

class DataSource extends Component {
  static propTpyes = {
    config: PropTypes.any,
    updateConfig: PropTypes.func
  }

  state = {
    dict: localStorage.getItem('lang') !== 'en-US' ? zhCN : enUS,
    visible: false,
    html: '',
    css: '',
    js: ''
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.props), fromJS(nextProps)) || !is(fromJS(this.state), fromJS(nextState))
  }

  trigger = () => {
    const { config } = this.props

    this.setState({
      visible: true,
      html: config.html || '',
      css: config.css || '',
      js: config.js || '',
    })
  }

  verifySubmit = () => {
    const { config } = this.props
    const { html, css, js } = this.state

    this.setState({
      visible: false
    })
    this.props.updateConfig({...config, html, css, js})
  }

  onHtmlChange = (val) => {
    this.setState({
      html: val
    })
  }

  onCssChange = (val) => {
    this.setState({
      css: val
    })
  }

  onJsChange = (val) => {
    this.setState({
      js: val
    })
  }

  render () {
    const { visible, dict, html, css, js } = this.state

    return (
      <div style={{display: 'inline-block'}}>
        <Icon title="代码编辑" style={{color: 'purple'}} type="form" onClick={() => this.trigger()} />
        <Modal
          wrapClassName="popview-modal code-sand-box-code-editor"
          title="内容编辑"
          visible={visible}
          width={950}
          maskClosable={false}
          okText={dict['model.submit']}
          onOk={this.verifySubmit}
          onCancel={() => { this.setState({ visible: false }) }}
          destroyOnClose
        >
          <Tabs>
            <TabPane tab="HTML" key="HTML">
              <CodeMirror mode="text/xml" theme="cobalt" value={html} onChange={this.onHtmlChange} />
            </TabPane>
            <TabPane tab="CSS" key="CSS">
              <CodeMirror mode="text/css" theme="cobalt" value={css} onChange={this.onCssChange} />
            </TabPane>
            <TabPane tab="JS" key="JS">
              <CodeMirror mode="text/javascript" theme="cobalt" value={js} onChange={this.onJsChange} />
            </TabPane>
          </Tabs>
        </Modal>
      </div>
    )
  }
}

export default DataSource